@@ -20,15 +20,28 @@ class testCache(unittest.TestCase):
     def test_init(self):
         self.assertTrue(os.access(self.cache.filename, os.F_OK))
 
+    def test_set(self):
+        self.cache.delete()
+        self.assertRaises(IOError, self.cache.set, "n", 43)
+
     def test_get(self):
         self.assertEqual(self.cache.get("n"), 43)
         self.assertEqual(self.cache.get("timer"), 1)
         time.sleep(1)
         self.assertEqual(self.cache.get("timer"), None)
+        self.assertEqual(self.cache.get("timer", True), 1)
         self.assertRaises(KeyError, self.cache.get, "j")
         self.cache.delete()
         self.assertRaises(IOError, self.cache.get, "j")
 
+    def test_invalidate(self):
+        self.assertEqual(self.cache.get("n"), 43)
+        self.cache.invalidate("n")
+        self.assertEqual(self.cache.get("n"), None)
+        self.assertRaises(KeyError, self.cache.invalidate, "j")
+        self.cache.delete()
+        self.assertRaises(IOError, self.cache.invalidate, "n")
+
     def test_remove(self):
         self.cache.remove("n")
         self.assertRaises(KeyError, self.cache.get, "n")
@@ -39,9 +52,6 @@ class testCache(unittest.TestCase):
     def test_flush(self):
         self.cache.flush()
         self.assertEqual(self.cache._read(), {})
-        self.cache.delete()
-        self.cache.flush()
-        self.assertEqual(self.cache._read(), {})
 
     def test_delete(self):
         self.cache.delete()
